@@ -1,17 +1,11 @@
 #!/usr/bin/perl -I. -w
 
-# use Aw;
 use Aw 'test@active:7449';
 require Aw::Client;
 require Aw::Event;
-use diagnostics;
 
 
 
-my $myName     = "XS Perl Time!";
-my $clientId   = 0;
-my $eventTypeName;
-
 print "Creating client...\n";
 my $client = newEZ Aw::Client ( "devkitClient" );
 
@@ -22,13 +16,13 @@ print "Publishing AdapterDevKit::timeRequest...\n";
 my $event = new Aw::Event ( $client, "AdapterDevKit::timeRequest" );
 
 $event->setTag ( 1 );
-print "  publish Error!\n" if ( $client->publish ( $event ) );
+$client->publish ( $event ) and die ( "Publish Error: $!" );
 
 
 print "Waiting for AdapterDevKit::time...\n";
 while ( $event = $client->getEvent( AW_INFINITE ) ) {
 
-	if ( ($eventTypeName = $event->getTypeName) eq "AdapterDevKit::time" ) {
+	if ( (my $eventTypeName = $event->getTypeName) eq "AdapterDevKit::time" ) {
 		my $eventTag = $event->getTag;
 
 		my $date = $event->getDateField ( "time" );
@@ -43,7 +37,6 @@ while ( $event = $client->getEvent( AW_INFINITE ) ) {
 	    	printf "Received \"%s\"\n", $eventTypeName;
 	}
 	undef ($event);
-	undef ($eventTypeName);
 
 }
 
