@@ -9,12 +9,11 @@ $VERSION = '0.1';
 
 sub getFieldNames
 {
-	my $result = Aw::Event::getFieldNamesRef ( @_ );
+	my $result = Aw::TypeDef::getFieldNamesRef ( @_ );
 	( wantarray ) ? @{ $result } : $result ;
 }
 
 
-
 #########################################################
 # Do not change this, Do not put anything below this.
 # File must return "true" value at termination
